[![PyPI](https://img.shields.io/pypi/v/meteomatics.svg)](https://pypi.python.org/pypi/meteomatics)

[![logo](https://www.meteomatics.com/wp-content/uploads/2019/01/meteomatics-logo_trans_sm-1.png)](http://www.meteomatics.com "Meteomatics - Your Experts in Weather Data Processing")

Python connector to the [Meteomatics Weather API](https://www.meteomatics.com/en/api/overview/ "Documentation Overview")
===================================================================================


Meteomatics provides a REST-style API to retrieve historic, current, and forecast data globally. This includes model data and observational data in time series and areal formats. Areal formats are also offered through a WMS/WFS-compatible interface. Geographic and time series data can be combined in certain file formats, such as NetCDF.


Install by typing `pip install meteomatics` in your favourite shell.

For a start we recommend to run the example script.
